/*
  Copyright 2006 Patrik Nilsson and Daniel Nilsson

  This file is part of shpirn.
  
  shpirn is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
	
  shpirn is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with shpirn; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/* logger.c:
   Used for a simpel log interface */

#include <stdio.h>
#include <stdarg.h>
#include <errno.h>
#include <string.h>
#include <time.h>

#include "shpirn.h"

FILE *log_file;

int logger_init( const char *file )
{
  /* inits the logger */
#ifndef DEBUG
  log_file = fopen( file, "a" );

  if( log_file != NULL )
	return TRUE;
  else
  {
	fprintf( stderr, "Error: %s\n", strerror(errno) );
	return FALSE;
  }
#else
  return TRUE;
#endif
}

void logger_write( char *fmt, ... )
{
  /* writes the log string to the file,
	 similar to printf */
  va_list ap;
  char buffer[20];
  time_t cur_time;
  struct tm *loctime;
  
  /* create time string */
  cur_time = time( NULL );
  loctime = localtime( &cur_time );
  strftime( buffer, sizeof( buffer ), "%b %d %H:%M:%S", loctime );
  
#ifndef DEBUG
  /* FIXME: I don't write DURING loggin to the file. */
  fprintf( log_file, "%s - ", buffer );
  va_start( ap, fmt );
  vfprintf( log_file, fmt, ap );
  va_end( ap );
#else
  printf( "LOG> %s - ", buffer );
  va_start( ap, fmt );
  vprintf( fmt, ap );
  va_end( ap );
  printf( "\n" );
#endif
}

void logger_close()
{
#ifndef DEBUG
  fclose( log_file );
#endif
}
